import 'package:flutter/material.dart';
import 'package:flutter_intro/step_widget_params.dart';

/// 引导步骤类
///
class IntroStep {
  /// 需要增加引导的 [Widget] 的 [GlobalKey]
  final GlobalKey key;

  /// 引导页内容生成方法，该方法会在引导页出现时由 [Intro] 内部调用，
  /// 并会将当前页面上的一些参数通过 [StepWidgetParams] 传进来
  final Widget Function(StepWidgetParams params) widgetBuilder;

  /// 生成 [IntroStep] 实例
  /// [key] 为 [GlobalKey]，需要同时将 [key] 传给需要增加引导页的 [Widget]
  /// [widgetBuilder] 为引导页生成方法
  IntroStep({
    @required this.key,
    @required this.widgetBuilder,
  })  : assert(key != null),
        assert(widgetBuilder != null);
}
